<?php
/**
 * Helper functions related to customizer and options
 *
 * @package Education_Soul
 */

if ( ! function_exists( 'education_soul_get_global_layout_options' ) ) :

	/**
	 * Returns global layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function education_soul_get_global_layout_options() {

		$choices = array(
			'left-sidebar'      => esc_html__( 'Primary Sidebar - Content', 'education-soul-pro' ),
			'right-sidebar'     => esc_html__( 'Content - Primary Sidebar', 'education-soul-pro' ),
			'three-columns'     => esc_html__( 'Three Columns ( Secondary - Content - Primary )', 'education-soul-pro' ),
			'three-columns-pcs' => esc_html__( 'Three Columns ( Primary - Content - Secondary )', 'education-soul-pro' ),
			'three-columns-cps' => esc_html__( 'Three Columns ( Content - Primary - Secondary )', 'education-soul-pro' ),
			'three-columns-psc' => esc_html__( 'Three Columns ( Primary - Secondary - Content )', 'education-soul-pro' ),
			'no-sidebar'        => esc_html__( 'No Sidebar', 'education-soul-pro' ),
		);
		$output  = apply_filters( 'education_soul_filter_layout_options', $choices );
		return $output;

	}

endif;

if ( ! function_exists( 'education_soul_get_site_layout_options' ) ) :

	/**
	 * Returns site layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function education_soul_get_site_layout_options() {

		$choices = array(
			'fluid' => esc_html__( 'Fluid', 'education-soul-pro' ),
			'boxed' => esc_html__( 'Boxed', 'education-soul-pro' ),
		);

		$output = apply_filters( 'education_soul_filter_site_layout_options', $choices );

		if ( ! empty( $output ) ) {
			ksort( $output );
		}

		return $output;

	}

endif;


if ( ! function_exists( 'education_soul_get_pagination_type_options' ) ) :

	/**
	 * Returns pagination type options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function education_soul_get_pagination_type_options() {

		$choices = array(
			'default' => esc_html__( 'Default', 'education-soul-pro' ),
			'numeric' => esc_html__( 'Numeric', 'education-soul-pro' ),
		);
		return $choices;

	}

endif;

if ( ! function_exists( 'education_soul_get_breadcrumb_type_options' ) ) :

	/**
	 * Returns breadcrumb type options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function education_soul_get_breadcrumb_type_options() {

		$choices = array(
			'disabled' => esc_html__( 'Disabled', 'education-soul-pro' ),
			'simple'   => esc_html__( 'Enabled', 'education-soul-pro' ),
		);
		return $choices;

	}

endif;

if ( ! function_exists( 'education_soul_get_archive_layout_options' ) ) :

	/**
	 * Returns archive layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function education_soul_get_archive_layout_options() {

		$choices = array(
			'full'    => esc_html__( 'Full Post', 'education-soul-pro' ),
			'excerpt' => esc_html__( 'Post Excerpt', 'education-soul-pro' ),
		);
		$output  = apply_filters( 'education_soul_filter_archive_layout_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'education_soul_get_image_sizes_options' ) ) :

	/**
	 * Returns image sizes options.
	 *
	 * @since 1.0.0
	 *
	 * @param bool  $add_disable True for adding No Image option.
	 * @param array $allowed Allowed image size options.
	 * @param bool  $show_dimension Enable or disable dimension.
	 * @return array Image size options.
	 */
	function education_soul_get_image_sizes_options( $add_disable = true, $allowed = array(), $show_dimension = true ) {

		global $_wp_additional_image_sizes;
		$get_intermediate_image_sizes = get_intermediate_image_sizes();
		$choices                      = array();
		if ( true === $add_disable ) {
			$choices['disable'] = esc_html__( 'No Image', 'education-soul-pro' );
		}
		$choices['thumbnail'] = esc_html__( 'Thumbnail', 'education-soul-pro' );
		$choices['medium']    = esc_html__( 'Medium', 'education-soul-pro' );
		$choices['large']     = esc_html__( 'Large', 'education-soul-pro' );
		$choices['full']      = esc_html__( 'Full (original)', 'education-soul-pro' );

		if ( true === $show_dimension ) {
			foreach ( array( 'thumbnail', 'medium', 'large' ) as $key => $_size ) {
				$choices[ $_size ] = $choices[ $_size ] . ' (' . get_option( $_size . '_size_w' ) . 'x' . get_option( $_size . '_size_h' ) . ')';
			}
		}

		if ( ! empty( $_wp_additional_image_sizes ) && is_array( $_wp_additional_image_sizes ) ) {
			foreach ( $_wp_additional_image_sizes as $key => $size ) {
				$choices[ $key ] = $key;
				if ( true === $show_dimension ) {
					$choices[ $key ] .= ' (' . $size['width'] . 'x' . $size['height'] . ')';
				}
			}
		}

		if ( ! empty( $allowed ) ) {
			foreach ( $choices as $key => $value ) {
				if ( ! in_array( $key, $allowed ) ) {
					unset( $choices[ $key ] );
				}
			}
		}

		return $choices;

	}

endif;


if ( ! function_exists( 'education_soul_get_image_alignment_options' ) ) :

	/**
	 * Returns image options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function education_soul_get_image_alignment_options() {

		$choices = array(
			'none'   => _x( 'None', 'alignment', 'education-soul-pro' ),
			'left'   => _x( 'Left', 'alignment', 'education-soul-pro' ),
			'center' => _x( 'Center', 'alignment', 'education-soul-pro' ),
			'right'  => _x( 'Right', 'alignment', 'education-soul-pro' ),
		);
		return $choices;

	}

endif;

if ( ! function_exists( 'education_soul_get_slider_caption_alignment_options' ) ) :

	/**
	 * Returns slider caption alignment options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function education_soul_get_slider_caption_alignment_options() {

		$choices = array(
			'left'   => esc_html_x( 'Left', 'alignment', 'education-soul-pro' ),
			'center' => esc_html_x( 'Center', 'alignment', 'education-soul-pro' ),
			'right'  => esc_html_x( 'Right', 'alignment', 'education-soul-pro' ),
		);
		return $choices;

	}

endif;

if ( ! function_exists( 'education_soul_get_featured_slider_transition_effects' ) ) :

	/**
	 * Returns the featured slider transition effects.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function education_soul_get_featured_slider_transition_effects() {

		$choices = array(
			'fade'       => _x( 'fade', 'transition effect', 'education-soul-pro' ),
			'fadeout'    => _x( 'fadeout', 'transition effect', 'education-soul-pro' ),
			'none'       => _x( 'none', 'transition effect', 'education-soul-pro' ),
			'scrollHorz' => _x( 'scrollHorz', 'transition effect', 'education-soul-pro' ),
			'tileSlide'  => _x( 'tileSlide', 'transition effect', 'education-soul-pro' ),
			'tileBlind'  => _x( 'tileBlind', 'transition effect', 'education-soul-pro' ),
			'flipHorz'   => _x( 'flipHorz', 'transition effect', 'education-soul-pro' ),
			'flipVert'   => _x( 'flipVert', 'transition effect', 'education-soul-pro' ),
		);
		$output  = apply_filters( 'education_soul_filter_featured_slider_transition_effects', $choices );

		if ( ! empty( $output ) ) {
			ksort( $output );
		}

		return $output;

	}

endif;

if ( ! function_exists( 'education_soul_get_featured_slider_type' ) ) :

	/**
	 * Returns the featured slider type.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function education_soul_get_featured_slider_type() {

		$choices = array(
			'featured-page'     => __( 'Featured Pages', 'education-soul-pro' ),
			'featured-category' => __( 'Featured Category', 'education-soul-pro' ),
			'featured-post'     => __( 'Featured Posts', 'education-soul-pro' ),
			'featured-image'    => __( 'Featured Images', 'education-soul-pro' ),
			'featured-tag'      => __( 'Featured Tag', 'education-soul-pro' ),
			'demo-slider'       => __( 'Demo Slider', 'education-soul-pro' ),
		);
		$output  = apply_filters( 'education_soul_filter_featured_slider_type', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'education_soul_get_customizer_font_options' ) ) :

	/**
	 * Returns customizer font options.
	 *
	 * @since 1.0.0
	 */
	function education_soul_get_customizer_font_options() {

		$web_fonts = education_soul_get_web_fonts();
		$os_fonts  = education_soul_get_os_fonts();

		$web_fonts = array_merge( $web_fonts, $os_fonts );

		if ( ! empty( $web_fonts ) ) {
			ksort( $web_fonts );
		}

		$choices = array();

		if ( ! empty( $web_fonts ) ) {
			foreach ( $web_fonts as $k => $v ) {
				$choices[ $k ] = esc_html( $v['label'] );
			}
		}
		return $choices;

	}

endif;

if ( ! function_exists( 'education_soul_get_web_fonts' ) ) :

	/**
	 * Returns web font options.
	 *
	 * @since 1.0.0
	 */
	function education_soul_get_web_fonts() {

		$choices = array(
			'philosopher'           => array(
				'name'  => 'Philosopher',
				'label' => "'Philosopher', sans-serif",
			),
			'bitter'                => array(
				'name'  => 'Bitter',
				'label' => "'Bitter', sans-serif",
			),

			'open-sans'             => array(
				'name'  => 'Open Sans',
				'label' => "'Open Sans', sans-serif",
			),
			'pt-sans'               => array(
				'name'  => 'PT Sans',
				'label' => "'PT Sans', sans-serif",
			),
			'merriweather-sans'     => array(
				'name'  => 'Merriweather Sans',
				'label' => "'Merriweather Sans', sans-serif",
			),
			'roboto'                => array(
				'name'  => 'Roboto',
				'label' => "'Roboto', sans-serif",
			),
			'creat-round'           => array(
				'name'  => 'Crete Round',
				'label' => 'Crete Round, Geneva, sans-serif',
			),
			'arizonia'              => array(
				'name'  => 'Arizonia',
				'label' => "'Arizonia', cursive",
			),
			'raleway'               => array(
				'name'  => 'Raleway',
				'label' => "'Raleway', sans-serif",
			),
			'poppins'               => array(
				'name'  => 'Poppins',
				'label' => "'Poppins', sans-serif",
			),
			'droid-sans'            => array(
				'name'  => 'Droid Sans',
				'label' => "'Droid Sans', sans-serif",
			),
			'lato'                  => array(
				'name'  => 'Lato',
				'label' => "'Lato', sans-serif",
			),
			'dosis'                 => array(
				'name'  => 'Dosis',
				'label' => "'Dosis', sans-serif",
			),
			'slabo-27px'            => array(
				'name'  => 'Slabo 27px',
				'label' => "'Slabo 27px', serif",
			),
			'oswald'                => array(
				'name'  => 'Oswald',
				'label' => "'Oswald', sans-serif",
			),
			'pt-sans-narrow'        => array(
				'name'  => 'PT Sans Narrow',
				'label' => "'PT Sans Narrow', sans-serif",
			),
			'josefin-slab'          => array(
				'name'  => 'Josefin Slab',
				'label' => "'Josefin Slab', serif",
			),
			'alegreya'              => array(
				'name'  => 'Alegreya',
				'label' => "'Alegreya', serif",
			),
			'exo'                   => array(
				'name'  => 'Exo',
				'label' => "'Exo', sans-serif",
			),
			'signika'               => array(
				'name'  => 'Signika',
				'label' => "'Signika', sans-serif",
			),
			'lobster'               => array(
				'name'  => 'Lobster',
				'label' => "'Lobster', cursive",
			),
			'indie-flower'          => array(
				'name'  => 'Indie Flower',
				'label' => "'Indie Flower', cursive",
			),
			'shadows-into-light'    => array(
				'name'  => 'Shadows Into Light',
				'label' => "'Shadows Into Light', cursive",
			),
			'kaushan-script'        => array(
				'name'  => 'Kaushan Script',
				'label' => "'Kaushan Script', cursive",
			),
			'dancing-script'        => array(
				'name'  => 'Dancing Script',
				'label' => "'Dancing Script', cursive",
			),
			'fredericka-the-great'  => array(
				'name'  => 'Fredericka the Great',
				'label' => "'Fredericka the Great', cursive",
			),
			'covered-by-your-grace' => array(
				'name'  => 'Covered By Your Grace',
				'label' => "'Covered By Your Grace', cursive",
			),

		);
		$choices = apply_filters( 'education_soul_filter_web_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}

		return $choices;

	}

endif;

if ( ! function_exists( 'education_soul_get_os_fonts' ) ) :

	/**
	 * Returns OS font options.
	 *
	 * @since 1.0.0
	 */
	function education_soul_get_os_fonts() {

		$choices = array(
			'arial'      => array(
				'name'  => 'Arial',
				'label' => "'Arial', sans-serif",
			),
			'georgia'    => array(
				'name'  => 'Georgia',
				'label' => "'Georgia', serif",
			),
			'cambria'    => array(
				'name'  => 'Cambria',
				'label' => "'Cambria', Georgia, serif",
			),
			'tahoma'     => array(
				'name'  => 'Tahoma',
				'label' => "'Tahoma', Geneva, sans-serif",
			),
			'sans-serif' => array(
				'name'  => 'Sans Serif',
				'label' => "'Sans Serif', Arial",
			),
			'verdana'    => array(
				'name'  => 'Verdana',
				'label' => "'Verdana', Geneva, sans-serif",
			),

		);
		$choices = apply_filters( 'education_soul_filter_os_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}
		return $choices;

	}

endif;

if ( ! function_exists( 'education_soul_get_font_family_from_key' ) ) :

	/**
	 * Return font family from font slug.
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Font slug.
	 * @return string Font name.
	 */
	function education_soul_get_font_family_from_key( $key ) {

		$output = '';

		$web_fonts = education_soul_get_web_fonts();
		$os_fonts  = education_soul_get_os_fonts();

		$fonts = array_merge( $web_fonts, $os_fonts );

		if ( isset( $fonts[ $key ] ) ) {
			$output = $fonts[ $key ]['label'];
		}
		return $output;

	}

endif;

if ( ! function_exists( 'education_soul_get_font_family_theme_settings_options' ) ) :

	/**
	 * Returns font family theme settings options.
	 *
	 * @since 1.0.0
	 */
	function education_soul_get_font_family_theme_settings_options() {

		$choices = array(
			'font_site_title'    => array(
				'label'   => __( 'Site Title', 'education-soul-pro' ),
				'default' => 'poppins',
			),
			'font_site_tagline'  => array(
				'label'   => __( 'Site Tagline', 'education-soul-pro' ),
				'default' => 'roboto',
			),
			'font_site_default'  => array(
				'label'   => __( 'Default', 'education-soul-pro' ),
				'default' => 'roboto',
			),

			'font_content_title' => array(
				'label'   => __( 'Content Title', 'education-soul-pro' ),
				'default' => 'poppins',
			),
			'font_content_body'  => array(
				'label'   => __( 'Content Body', 'education-soul-pro' ),
				'default' => 'roboto',
			),
			'font_heading_tags'  => array(
				'label'   => __( 'Heading Tags', 'education-soul-pro' ),
				'default' => 'poppins',
			),
			'font_navigation'    => array(
				'label'   => __( 'Navigation', 'education-soul-pro' ),
				'default' => 'poppins',
			),

		);
		return $choices;

	}

endif;

if ( ! function_exists( 'education_soul_get_default_colors' ) ) :

	/**
	 * Returns default colors.
	 *
	 * @since 1.0.0
	 *
	 * @param string $scheme Color scheme.
	 * @return array Color values based on scheme.
	 */
	function education_soul_get_default_colors( $scheme = 'default' ) {

		$output = array();

		switch ( $scheme ) {

			case 'default':
			default:
				$output = array(
					// Basic.
					'color_basic_text'                     => '#727272',
					'color_basic_link'                     => '#007acc',
					'color_basic_link_hover'               => '#1a1a1a',
					'color_basic_heading'                  => '#00387d',
					'color_basic_page_title'               => '#00387d',
					'color_basic_button_background'        => '#aa0000',
					'color_basic_button_text'              => '#ffffff',
					'color_basic_button_background_hover'  => '#1d6ea5',
					'color_basic_button_text_hover'        => '#ffffff',
					'color_basic_button_secondary_background'        => '#002147',
					'color_basic_button_secondary_text'              => '#ffffff',
					'color_basic_button_secondary_background_hover'  => '#1d6ea5',
					'color_basic_button_secondary_text_hover'        => '#ffffff',

					// Top Header.
					'color_top_header_background'          => '#002147',
					'color_top_header_news_title_background' => '#aa0000',
					'color_top_header_news_title'          => '#ffffff',
					'color_top_header_news_text'          => '#ffffff',
					'color_top_header_link'                => '#ffffff',
					'color_top_header_link_hover'          => '#ffffff',

					// Header.
					'color_header_background'              => '#fbfbfb',
					'color_header_title'                   => '#007acc',
					'color_header_title_hover'             => '#1a1a1a',
					'color_header_tagline'                 => '#ffffff',


					// Primary Menu.
					'color_primary_menu_link'              => '#000000',
					'color_primary_menu_link_hover'        => '#aa0000',
					'color_primary_menu_submenu_background' => '#ffffff',
					'color_primary_submenu_link'           => '#000000',
					'color_primary_submenu_link_hover'     => '#aa0000',

					// Slider.
					'color_slider_caption_text'            => '#ffffff',
					'color_slider_caption_link'            => '#ffffff',
					'color_slider_caption_link_hover'      => '#ffffff',
					'color_slider_icon'                    => '#ffffff',
					'color_slider_icon_hover'              => '#ffffff',
					'color_slider_icon_background'         => '#333333',
					'color_slider_icon_background_hover'   => '#3770ab',
					'color_slider_pager'                   => '#ffffff',
					'color_slider_pager_active'            => '#aa0000',
					'color_slider_primary_button'          => '#ffffff',
					'color_slider_secondary_button'        => '#ffffff',
					'color_slider_primary_button_background' => '#aa0000',
					'color_slider_secondary_button_background' => '#002147',
					'color_slider_primary_button_hover'          => '#ffffff',
					'color_slider_secondary_button_hover'        => '#ffffff',
					'color_slider_primary_button_background_hover' => '#00448b',
					'color_slider_secondary_button_background_hover' => '#00448b',

					// Content.
					'color_content_background'             => '#fbfbfb',
					'color_primary_content_background'     => '#ffffff',
					'color_content_title'                  => '#00387d',
					'color_content_text'                   => '#727272',
					'color_content_link'                   => '#007acc',
					'color_content_link_hover'             => '#1a1a1a',
					'color_content_meta_link'              => '#007acc',
					'color_content_meta_link_hover'        => '#1a1a1a',
					'color_content_meta_icon'              => '#807a7a',
					'color_content_meta_date'              => '#ffffff',
					'color_content_meta_date_month_background' => '#002147',
					'color_content_meta_date_day_background' => '#f7f7f7',

					// Sidebar.
					'color_sidebar_widget_background'      => '#ffffff',
					'color_sidebar_title'                  => '#00387d',
					'color_sidebar_text'                   => '#727272',
					'color_sidebar_link'                   => '#001837',
					'color_sidebar_link_hover'             => '#179bd7',
					'color_sidebar_list_icon'              => '#001837',

					// Home Page Widgets.
					'color_home_widgets_background'        => '#ffffff',
					'color_home_widgets_title'             => '#00387d',
					'color_home_widgets_text'              => '#727272',
					'color_home_widgets_link'              => '#253b80',
					'color_home_widgets_link_hover'        => '#179bd7',

					// CTA Section.
					'color_cta_section_background'         => '#002147',
					'color_cta_section_overlay'            => '#002147',
					'color_cta_main_section_title'         => '#ffffff',
					'color_cta_section_text'               => '#ffffff',
					'color_cta_section_button'             => '#ffffff',
					'color_cta_section_button_hover'       => '#ffffff',
					'color_cta_section_button_background'  => '#aa0000',
					'color_cta_section_button_background_hover' => '#253b80',

					// Section Testimonial.
					'color_testimonial_section_background' 			=> '#4a4a4a',
					'color_testimonial_section_overlay'				=> '#002147',
					'color_testimonial_main_section_title' 			=> '#ffffff',
					'color_testimonial_main_section_title_border'	=> '#aa0000',
					'color_testimonial_section_title'      			=> '#4a4a4a',
					'color_testimonial_section_content'    			=> '#727272',


					// Section Team.
					'color_team_section_background'        => '#fbfbfb',
					'color_team_main_section_title'        => '#00387d',
					'color_team_main_section_title_border' => '#aa0000',
					'color_team_section_title'             => '#00387d',
					'color_team_section_title_hover'  => '#222222',
					'color_team_section_title_background'  => '#222222',


					// Section Service.
					'color_service_section_background'     => '#ffffff',
					'color_service_main_section_title'     => '#00387d',
					'color_service_main_section_title_border' => '#aa0000',
					'color_service_section_title'          => '#ffffff',
					'color_service_section_title_hover' => '#ffffff',

					// Section News and Events.
					'color_news_events_section_background' => '#fbfbfb',
					'color_news_events_main_section_title' => '#253b80',
					'color_news_events_main_section_title_border' => '#aa0000',
					'color_news_events_section_text'       => '#272727',
					'color_news_events_section_link'      => '#007acc',
					'color_news_events_section_link_hover' => '#1a1a1a',
					'color_news_events_section_title'      => '#272727',
					'color_news_events_section_title_hover'       => '#179bd7',
					'color_news_events_section_content_background' => '#ffffff',


					// Section Latest News.
					'color_latest_news_section_background' => '#fbfbfb',
					'color_latest_news_main_section_title' => '#253b80',
					'color_latest_news_main_section_title_border' => '#aa0000',
					'color_latest_news_section_title'      => '#253b80',
					'color_latest_news_section_title_hover' => '#179bd7',
					'color_latest_news_section_text'       => '#272727',
					'color_latest_news_section_content_background' => '#ffffff',
					'color_latest_news_section_link' => '#007acc',
					'color_latest_news_section_link_hover'    => '#179bd7',
					'color_latest_news_section_button'     => '#ffffff',
					'color_latest_news_section_button_hover' => '#179bd7',
					'color_latest_news_section_button_background' => '#ffffff',
					'color_latest_news_section_button_background_hover' => '#ffffff',

					// Section Featured Blocks News.
					'color_featured_blocks_section_background' => '#002147',
					'color_featured_blocks_main_section_title' => '#ffffff',
					'color_featured_blocks_main_section_title_border' => '#aa0000',
					'color_featured_blocks_section_title'  => '#ffffff',
					'color_featured_blocks_section_text'   => '#ffffff',
					'color_featured_blocks_section_title_hover' => '#ffffff',
					'color_featured_blocks_section_button' => '#272727',
					'color_featured_blocks_section_button_hover' => '#ffffff',
					'color_featured_blocks_section_button_background' => '#ffffff',
					'color_featured_blocks_section_button_background_hover' => '#ffffff',

					// Footer Widgets.
					'color_footer_widgets_background'      => '#080f1e',
					'color_footer_widgets_title'           => '#ffffff',
					'color_footer_widgets_title_border'           => '#ffffff',

					'color_footer_widgets_text'            => '#c1c3c6',
					'color_footer_widgets_link'            => '#c1c3c6',
					'color_footer_widgets_link_hover'      => '#ffffff',

					// Footer area.
					'color_footer_area_background'         => '#080f1e',
					'color_footer_area_copyright_background'         => '#0f192f',
					'color_footer_area_text'               => '#ffffff',
					'color_footer_area_link'               => '#ffffff',
					'color_footer_area_link_hover'         => '#ffffff',

					// Go To Top.
					'color_goto_top_icon'                  => '#222222',
					'color_goto_top_icon_hover'            => '#ffffff',
					'color_goto_top_background'            => '#179bd7',
					'color_goto_top_background_hover'      => '#002147',

					// Pagination.
					'color_pagination_link'                => '#222222',
					'color_pagination_link_hover'          => '#fff',
					'color_pagination_link_background'     => '#f3f0f0',
					'color_pagination_link_background_hover' => '#007acc',

					// Breadcrumb.
					'color_breadcrumb_background'          => '#ffffff',
					'color_breadcrumb_link'                => '#007acc',
					'color_breadcrumb_link_hover'          => '#1a1a1a',
					'color_breadcrumb_text'                => '#1a1a1a',

				);
				break;

		} // End switch.

		return $output;

	}

endif;


if ( ! function_exists( 'education_soul_get_color_theme_settings_options' ) ) :

	/**
	 * Returns color theme settings options.
	 *
	 * @since 1.0.0
	 */
	function education_soul_get_color_theme_settings_options() {

		$choices = array(

			// Basic.
			'color_basic_text'                             => array(
				'label'   => __( 'Text Color', 'education-soul-pro' ),
				'section' => 'color_section_basic',
			),
			'color_basic_link'                             => array(
				'label'   => __( 'Link Color', 'education-soul-pro' ),
				'section' => 'color_section_basic',
			),
			'color_basic_link_hover'                       => array(
				'label'   => __( 'Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_basic',
			),
			'color_basic_heading'                          => array(
				'label'   => __( 'Heading Color', 'education-soul-pro' ),
				'section' => 'color_section_basic',
			),
			'color_basic_page_title'                       => array(
				'label'   => __( 'Page Title Color', 'education-soul-pro' ),
				'section' => 'color_section_basic',
			),
			'color_basic_button_text'                      => array(
				'label'   => __( 'Button Primary Text Color', 'education-soul-pro' ),
				'section' => 'color_section_basic',
			),
			'color_basic_button_background'                => array(
				'label'   => __( 'Button Primary Background Color', 'education-soul-pro' ),
				'section' => 'color_section_basic',
			),
			'color_basic_button_text_hover'                => array(
				'label'   => __( 'Button Primary Text Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_basic',
			),
			'color_basic_button_background_hover'          => array(
				'label'   => __( 'Button Primary Background Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_basic',
			),
			'color_basic_button_secondary_text'                      => array(
				'label'   => __( 'Button Secondary Text Color', 'education-soul-pro' ),
				'section' => 'color_section_basic',
			),
			'color_basic_button_secondary_background'                => array(
				'label'   => __( 'Button Secondary Background Color', 'education-soul-pro' ),
				'section' => 'color_section_basic',
			),
			'color_basic_button_secondary_text_hover'                => array(
				'label'   => __( 'Button Secondary Text Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_basic',
			),
			'color_basic_button_secondary_background_hover'          => array(
				'label'   => __( 'Button Secondary Background Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_basic',
			),
			// Top Header Header.
			'color_top_header_background'                  => array(
				'label'   => __( 'Background Color', 'education-soul-pro' ),
				'section' => 'color_section_top_header',
			),
			'color_top_header_news_title_background'       => array(
				'label'   => __( 'Notice Title Background', 'education-soul-pro' ),
				'section' => 'color_section_top_header',
			),
			'color_top_header_news_title'                  => array(
				'label'   => __( 'Notice Text Background', 'education-soul-pro' ),
				'section' => 'color_section_top_header',
			),
			'color_top_header_news_text'                  => array(
				'label'   => __( 'Top Header Text Color', 'education-soul-pro' ),
				'section' => 'color_section_top_header',
			),
			'color_top_header_link'                        => array(
				'label'   => __( 'Top Header Link Color', 'education-soul-pro' ),
				'section' => 'color_section_top_header',
			),
			'color_top_header_link_hover'                  => array(
				'label'   => __( 'Top Header Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_top_header',
			),

			// Header.
			'color_header_background'                      => array(
				'label'   => __( 'Background Color', 'education-soul-pro' ),
				'section' => 'color_section_header',
			),
			'color_header_title'                           => array(
				'label'   => __( 'Site Title Color', 'education-soul-pro' ),
				'section' => 'color_section_header',
			),
			'color_header_title_hover'                     => array(
				'label'   => __( 'Site Title Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_header',
			),
			'color_header_tagline'                         => array(
				'label'   => __( 'Site Tagline Color', 'education-soul-pro' ),
				'section' => 'color_section_header',
			),


			// Primary Menu.

			'color_primary_menu_link'                      => array(
				'label'   => __( 'Link Color', 'education-soul-pro' ),
				'section' => 'color_section_primary_menu',
			),
			'color_primary_menu_link_hover'                => array(
				'label'   => __( 'Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_primary_menu',
			),
			'color_primary_menu_submenu_background'     => array(
				'label'   => __( 'Submenu Background', 'education-soul-pro' ),
				'section' => 'color_section_primary_menu',
			),
			'color_primary_submenu_link'                   => array(
				'label'   => __( 'Submenu Link Color', 'education-soul-pro' ),
				'section' => 'color_section_primary_menu',
			),
			'color_primary_submenu_link_hover'             => array(
				'label'   => __( 'Submenu Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_primary_menu',
			),

			// Content.
			'color_content_background'                     => array(
				'label'   => __( 'Background Color', 'education-soul-pro' ),
				'section' => 'color_section_content',
			),
			'color_primary_content_background'             => array(
				'label'   => __( 'Content Block Background Color', 'education-soul-pro' ),
				'section' => 'color_section_content',
			),
			'color_content_title'                          => array(
				'label'   => __( 'Title Color', 'education-soul-pro' ),
				'section' => 'color_section_content',
			),
			'color_content_text'                           => array(
				'label'   => __( 'Text Color', 'education-soul-pro' ),
				'section' => 'color_section_content',
			),
			'color_content_link'                           => array(
				'label'   => __( 'Link Color', 'education-soul-pro' ),
				'section' => 'color_section_content',
			),
			'color_content_link_hover'                     => array(
				'label'   => __( 'Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_content',
			),
			'color_content_meta_link'                      => array(
				'label'   => __( 'Meta Link Color', 'education-soul-pro' ),
				'section' => 'color_section_content',
			),
			'color_content_meta_link_hover'                => array(
				'label'   => __( 'Meta Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_content',
			),
			'color_content_meta_icon'                      => array(
				'label'   => __( 'Meta Icon Color', 'education-soul-pro' ),
				'section' => 'color_section_content',
			),
			'color_content_meta_date'                      => array(
				'label'   => __( 'Meta Date Color', 'education-soul-pro' ),
				'section' => 'color_section_content',
			),
			'color_content_meta_date_day_background'       => array(
				'label'   => __( 'Meta Day Background Color', 'education-soul-pro' ),
				'section' => 'color_section_content',
			),
			'color_content_meta_date_month_background'     => array(
				'label'   => __( 'Meta Month Background Color', 'education-soul-pro' ),
				'section' => 'color_section_content',
			),

			// Slider.
			'color_slider_caption_text'                    => array(
				'label'   => __( 'Text Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_caption_link'                    => array(
				'label'   => __( 'Link Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_caption_link_hover'              => array(
				'label'   => __( 'Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_icon'                            => array(
				'label'   => __( 'Icon Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_icon_hover'                      => array(
				'label'   => __( 'Icon Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_icon_background'                 => array(
				'label'   => __( 'Icon Background Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_icon_background_hover'           => array(
				'label'   => __( 'Icon Background Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_pager'                           => array(
				'label'   => __( 'Pager Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_pager_active'                    => array(
				'label'   => __( 'Pager Active Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_primary_button'                  => array(
				'label'   => __( 'Primary Button Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_primary_button_hover'                  => array(
				'label'   => __( 'Primary Button Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_secondary_button'                => array(
				'label'   => __( 'Secondary Button Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_secondary_button_hover'                => array(
				'label'   => __( 'Secondary Button Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_primary_button_background'       => array(
				'label'   => __( 'Primary Button Background Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_primary_button_background_hover'       => array(
				'label'   => __( 'Primary Button Background Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_secondary_button_background'     => array(
				'label'   => __( 'Secondary Button Background Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),
			'color_slider_secondary_button_background_hover'     => array(
				'label'   => __( 'Secondary Button Background Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_slider',
			),

			// Home Page Widgets.
			'color_home_widgets_background'                => array(
				'label'   => __( 'Widget Background Color', 'education-soul-pro' ),
				'section' => 'color_section_home_widgets',
			),
			'color_home_widgets_title'                     => array(
				'label'   => __( 'Widget Title Color', 'education-soul-pro' ),
				'section' => 'color_section_home_widgets',
			),
			'color_home_widgets_text'                      => array(
				'label'   => __( 'Text Color', 'education-soul-pro' ),
				'section' => 'color_section_home_widgets',
			),
			'color_home_widgets_link'                      => array(
				'label'   => __( 'Link Color', 'education-soul-pro' ),
				'section' => 'color_section_home_widgets',
			),
			'color_home_widgets_link_hover'                => array(
				'label'   => __( 'Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_home_widgets',
			),

			// Sidebar.
			'color_sidebar_widget_background'              => array(
				'label'   => __( 'Widget Background Color', 'education-soul-pro' ),
				'section' => 'color_section_sidebar',
			),
			'color_sidebar_title'                          => array(
				'label'   => __( 'Title Color', 'education-soul-pro' ),
				'section' => 'color_section_sidebar',
			),
			'color_sidebar_text'                           => array(
				'label'   => __( 'Text Color', 'education-soul-pro' ),
				'section' => 'color_section_sidebar',
			),
			'color_sidebar_link'                           => array(
				'label'   => __( 'Link Color', 'education-soul-pro' ),
				'section' => 'color_section_sidebar',
			),
			'color_sidebar_link_hover'                     => array(
				'label'   => __( 'Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_sidebar',
			),
			'color_sidebar_list_icon'                      => array(
				'label'   => __( 'List Icon Color', 'education-soul-pro' ),
				'section' => 'color_section_sidebar',
			),

			// Footer area.
			'color_footer_area_background'                 => array(
				'label'   => __( 'Background Color', 'education-soul-pro' ),
				'section' => 'color_section_footer_area',
			),
			'color_footer_area_copyright_background'                 => array(
				'label'   => __( 'Copyright Background Color', 'education-soul-pro' ),
				'section' => 'color_section_footer_area',
			),
			'color_footer_area_text'                       => array(
				'label'   => __( 'Text Color', 'education-soul-pro' ),
				'section' => 'color_section_footer_area',
			),
			'color_footer_area_link'                       => array(
				'label'   => __( 'Link Color', 'education-soul-pro' ),
				'section' => 'color_section_footer_area',
			),
			'color_footer_area_link_hover'                 => array(
				'label'   => __( 'Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_footer_area',
			),

			// Go To Top.
			'color_goto_top_icon'                          => array(
				'label'   => __( 'Icon Color', 'education-soul-pro' ),
				'section' => 'color_section_goto_top',
			),
			'color_goto_top_icon_hover'                    => array(
				'label'   => __( 'Icon Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_goto_top',
			),
			'color_goto_top_background'                    => array(
				'label'   => __( 'Background Color', 'education-soul-pro' ),
				'section' => 'color_section_goto_top',
			),
			'color_goto_top_background_hover'              => array(
				'label'   => __( 'Background Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_goto_top',
			),

			// Pagination.
			'color_pagination_link'                        => array(
				'label'   => __( 'Link Color', 'education-soul-pro' ),
				'section' => 'color_section_pagination',
			),
			'color_pagination_link_hover'                  => array(
				'label'   => __( 'Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_pagination',
			),
			'color_pagination_link_background'             => array(
				'label'   => __( 'Link Background Color', 'education-soul-pro' ),
				'section' => 'color_section_pagination',
			),
			'color_pagination_link_background_hover'       => array(
				'label'   => __( 'Link Background Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_pagination',
			),

			// Breadcrumb.
			'color_breadcrumb_background'                  => array(
				'label'   => __( 'background Color', 'education-soul-pro' ),
				'section' => 'color_section_breadcrumb',
			),
			'color_breadcrumb_link'                        => array(
				'label'   => __( 'Link Color', 'education-soul-pro' ),
				'section' => 'color_section_breadcrumb',
			),
			'color_breadcrumb_link_hover'                  => array(
				'label'   => __( 'Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_breadcrumb',
			),
			'color_breadcrumb_text'                        => array(
				'label'   => __( 'Text Color', 'education-soul-pro' ),
				'section' => 'color_section_breadcrumb',
			),

			// Specific section testimonial.
			'color_testimonial_section_background'         => array(
				'label'   => __( 'Section Background Color', 'education-soul-pro' ),
				'section' => 'color_section_testimonial_section',
			),
			'color_testimonial_section_overlay'         => array(
				'label'   => __( 'Section Background Overlay Color', 'education-soul-pro' ),
				'section' => 'color_section_testimonial_section',
			),
			'color_testimonial_main_section_title'         => array(
				'label'   => __( 'Section Main Title Color', 'education-soul-pro' ),
				'section' => 'color_section_testimonial_section',
			),
			'color_testimonial_main_section_title_border'         => array(
				'label'   => __( 'Section Main Title Border Color', 'education-soul-pro' ),
				'section' => 'color_section_testimonial_section',
			),
			'color_testimonial_section_title'              => array(
				'label'   => __( 'Section Title Color', 'education-soul-pro' ),
				'section' => 'color_section_testimonial_section',
			),
			'color_testimonial_section_content'            => array(
				'label'   => __( 'Content Color', 'education-soul-pro' ),
				'section' => 'color_section_testimonial_section',
			),


			// Specific section service.
			'color_service_section_background'             => array(
				'label'   => __( 'Section Background Color', 'education-soul-pro' ),
				'section' => 'color_section_service_section',
			),
			'color_service_main_section_title'             => array(
				'label'   => __( 'Main Section Title Color', 'education-soul-pro' ),
				'section' => 'color_section_service_section',
			),
			'color_service_main_section_title_border'         => array(
				'label'   => __( 'Section Main Title Border Color', 'education-soul-pro' ),
				'section' => 'color_section_service_section',
			),
			'color_service_section_title'                  => array(
				'label'   => __( 'Title Color', 'education-soul-pro' ),
				'section' => 'color_section_service_section',
			),
			'color_service_section_title_hover'       => array(
				'label'   => __( 'Title Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_service_section',
			),

			// Specific section News and events.
			'color_news_events_section_background'         => array(
				'label'   => __( 'Section Background Color', 'education-soul-pro' ),
				'section' => 'color_section_news_events_section',
			),
			'color_news_events_main_section_title'         => array(
				'label'   => __( 'Main Section Title Color', 'education-soul-pro' ),
				'section' => 'color_section_news_events_section',
			),
			'color_news_events_main_section_title_border'         => array(
				'label'   => __( 'Section Main Title Border Color', 'education-soul-pro' ),
				'section' => 'color_section_news_events_section',
			),
			'color_news_events_section_text'               => array(
				'label'   => __( 'Text Color', 'education-soul-pro' ),
				'section' => 'color_section_news_events_section',
			),
			'color_news_events_section_title'              => array(
				'label'   => __( 'Title Color', 'education-soul-pro' ),
				'section' => 'color_section_news_events_section',
			),
			'color_news_events_section_title_hover'        => array(
				'label'   => __( 'Title Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_news_events_section',
			),
			'color_news_events_section_link'              => array(
				'label'   => __( 'Link Color', 'education-soul-pro' ),
				'section' => 'color_section_news_events_section',
			),
			'color_news_events_section_link_hover'        => array(
				'label'   => __( 'Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_news_events_section',
			),
			'color_news_events_section_content_background' => array(
				'label'   => __( 'Content Background Color', 'education-soul-pro' ),
				'section' => 'color_section_news_events_section',
			),

			// Specific section latest news.
			'color_latest_news_section_background'         => array(
				'label'   => __( 'Section Background Color', 'education-soul-pro' ),
				'section' => 'color_section_latest_news_section',
			),
			'color_latest_news_main_section_title'         => array(
				'label'   => __( 'Main Section Title Color', 'education-soul-pro' ),
				'section' => 'color_section_latest_news_section',
			),
			'color_latest_news_main_section_title_border'         => array(
				'label'   => __( 'Section Main Title Border Color', 'education-soul-pro' ),
				'section' => 'color_section_latest_news_section',
			),
			'color_latest_news_section_text'               => array(
				'label'   => __( 'Text Color', 'education-soul-pro' ),
				'section' => 'color_section_latest_news_section',
			),
			'color_latest_news_section_title'              => array(
				'label'   => __( 'Title Color', 'education-soul-pro' ),
				'section' => 'color_section_latest_news_section',
			),
			'color_latest_news_section_title_hover'        => array(
				'label'   => __( 'Title Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_latest_news_section',
			),
			'color_latest_news_section_content_background' => array(
				'label'   => __( 'Content Background Color', 'education-soul-pro' ),
				'section' => 'color_section_latest_news_section',
			),
			'color_latest_news_section_link'         => array(
				'label'   => __( 'Content Link Color', 'education-soul-pro' ),
				'section' => 'color_section_latest_news_section',
			),
			'color_latest_news_section_link_hover'         => array(
				'label'   => __( 'Content Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_latest_news_section',
			),
			'color_latest_news_section_button'             => array(
				'label'   => __( 'Button Color', 'education-soul-pro' ),
				'section' => 'color_section_latest_news_section',
			),
			'color_latest_news_section_button_hover'       => array(
				'label'   => __( 'Button Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_latest_news_section',
			),
			'color_latest_news_section_button_background'  => array(
				'label'   => __( 'Button Background Color', 'education-soul-pro' ),
				'section' => 'color_section_latest_news_section',
			),
			'color_latest_news_section_button_background_hover' => array(
				'label'   => __( 'Button Background Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_latest_news_section',
			),

			// Specific section featured bloks.
			'color_featured_blocks_section_background' => array(
				'label'   => __( 'Section Background Color', 'education-soul-pro' ),
				'section' => 'color_section_featured_blocks_section',
			),
			'color_featured_blocks_main_section_title'         => array(
				'label'   => __( 'Section Main Title Color', 'education-soul-pro' ),
				'section' => 'color_section_featured_blocks_section',
			),
			'color_featured_blocks_main_section_title_border'         => array(
				'label'   => __( 'Section Main Title Border Color', 'education-soul-pro' ),
				'section' => 'color_section_featured_blocks_section',
			),
			'color_featured_blocks_section_text'           => array(
				'label'   => __( 'Text Color', 'education-soul-pro' ),
				'section' => 'color_section_featured_blocks_section',
			),
			'color_featured_blocks_section_title'          => array(
				'label'   => __( 'Title Color', 'education-soul-pro' ),
				'section' => 'color_section_featured_blocks_section',
			),
			'color_featured_blocks_section_title_hover'    => array(
				'label'   => __( 'Title Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_featured_blocks_section',
			),

			'color_featured_blocks_section_button'         => array(
				'label'   => __( 'Button Color', 'education-soul-pro' ),
				'section' => 'color_section_featured_blocks_section',
			),
			'color_featured_blocks_section_button_hover'   => array(
				'label'   => __( 'Button Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_featured_blocks_section',
			),
			'color_featured_blocks_section_button_background' => array(
				'label'   => __( 'Button Background Color', 'education-soul-pro' ),
				'section' => 'color_section_featured_blocks_section',
			),
			'color_featured_blocks_section_button_background_hover' => array(
				'label'   => __( 'Button Background Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_featured_blocks_section',
			),

			// Specific section CTA.
			'color_cta_section_background'                 => array(
				'label'   => __( 'Seciton Background Color', 'education-soul-pro' ),
				'section' => 'color_section_cta_section',
			),
			'color_cta_section_overlay'                 => array(
				'label'   => __( 'Seciton Overlay Color', 'education-soul-pro' ),
				'section' => 'color_section_cta_section',
			),
			'color_cta_main_section_title'                 => array(
				'label'   => __( 'Title Color', 'education-soul-pro' ),
				'section' => 'color_section_cta_section',
			),
			'color_cta_section_text'                       => array(
				'label'   => __( 'Text Color', 'education-soul-pro' ),
				'section' => 'color_section_cta_section',
			),
			'color_cta_section_button'                     => array(
				'label'   => __( 'Button Color', 'education-soul-pro' ),
				'section' => 'color_section_cta_section',
			),
			'color_cta_section_button_hover'               => array(
				'label'   => __( 'Button Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_cta_section',
			),
			'color_cta_section_button_background'          => array(
				'label'   => __( 'Button Background Color', 'education-soul-pro' ),
				'section' => 'color_section_cta_section',
			),
			'color_cta_section_button_background_hover'    => array(
				'label'   => __( 'Button Background Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_cta_section',
			),

			// Specific section team.
			'color_team_section_background'                => array(
				'label'   => __( 'Section Background Color', 'education-soul-pro' ),
				'section' => 'color_section_team_section',
			),
			'color_team_main_section_title'                => array(
				'label'   => __( 'Main Section Title Color', 'education-soul-pro' ),
				'section' => 'color_section_team_section',
			),

			'color_team_main_section_title_border'         => array(
				'label'   => __( 'Section Main Title Border Color', 'education-soul-pro' ),
				'section' => 'color_section_team_section',
			),
			'color_team_section_title'                     => array(
				'label'   => __( 'Title Color', 'education-soul-pro' ),
				'section' => 'color_section_team_section',
			),
			'color_team_section_title_hover'          => array(
				'label'   => __( 'Title Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_team_section',
			),
			'color_team_section_title_background'          => array(
				'label'   => __( 'Title Background Color', 'education-soul-pro' ),
				'section' => 'color_section_team_section',
			),

			// Footer widgets.
			'color_footer_widgets_background'              => array(
				'label'   => __( 'Background Color', 'education-soul-pro' ),
				'section' => 'color_section_footer_widgets',
			),
			'color_footer_widgets_title'                   => array(
				'label'   => __( 'Title Color', 'education-soul-pro' ),
				'section' => 'color_section_footer_widgets',
			),
			'color_footer_widgets_title_border'                   => array(
				'label'   => __( 'Title Border Color', 'education-soul-pro' ),
				'section' => 'color_section_footer_widgets',
			),
			'color_footer_widgets_text'                    => array(
				'label'   => __( 'Text Color', 'education-soul-pro' ),
				'section' => 'color_section_footer_widgets',
			),
			'color_footer_widgets_link'                    => array(
				'label'   => __( 'Link Color', 'education-soul-pro' ),
				'section' => 'color_section_footer_widgets',
			),
			'color_footer_widgets_link_hover'              => array(
				'label'   => __( 'Link Hover Color', 'education-soul-pro' ),
				'section' => 'color_section_footer_widgets',
			),

		);

		return $choices;

	}

endif;

if ( ! function_exists( 'education_soul_get_color_panels_options' ) ) :

	/**
	 * Returns color panels options.
	 *
	 * @since 1.0.0
	 */
	function education_soul_get_color_panels_options() {

		$choices = array(
			'color_panel_main'    => array(
				'label' => __( 'Color Options', 'education-soul-pro' ),
			),
			'color_panel_section' => array(
				'label' => __( 'Home Section Color Options', 'education-soul-pro' ),
			),
		);
		return $choices;
	}

endif;
if ( ! function_exists( 'education_soul_get_color_sections_options' ) ) :

	/**
	 * Returns color sections options.
	 *
	 * @since 1.0.0
	 */
	function education_soul_get_color_sections_options() {

		$choices = array(
			'color_section_basic'                   => array(
				'label' => __( 'Basic Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_main',
			),
			'color_section_top_header'              => array(
				'label' => __( 'Top Header Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_main',
			),
			'color_section_header'                  => array(
				'label' => __( 'Header Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_main',
			),
			'color_section_primary_menu'            => array(
				'label' => __( 'Primary Menu Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_main',
			),
			'color_section_slider'                  => array(
				'label' => __( 'Slider Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_main',
			),
			'color_section_content'                 => array(
				'label' => __( 'Content Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_main',
			),
			'color_section_sidebar'                 => array(
				'label' => __( 'Sidebar Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_main',
			),
			'color_section_breadcrumb'              => array(
				'label' => __( 'Breadcrumb Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_main',
			),
			'color_section_goto_top'                => array(
				'label' => __( 'Go To Top Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_main',
			),
			'color_section_pagination'              => array(
				'label' => __( 'Pagination Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_main',
			),
			'color_section_footer_widgets'          => array(
				'label' => __( 'Footer Widgets Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_main',
			),
			'color_section_footer_bottom_widgets'   => array(
				'label' => __( 'Footer Bottom Widgets Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_main',
			),
			'color_section_footer_area'             => array(
				'label' => __( 'Footer Area Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_main',
			),
			'color_section_home_section'            => array(
				'label' => __( 'Default Options', 'education-soul-pro' ),
				'panel' => 'color_panel_section',
			),
			'color_section_testimonial_section'     => array(
				'label' => __( 'Testimonial Section Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_section',
			),
			'color_section_news_events_section'     => array(
				'label' => __( 'News/Events Section Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_section',
			),
			'color_section_service_section'         => array(
				'label' => __( 'Service Section Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_section',
			),
			'color_section_latest_news_section'     => array(
				'label' => __( 'Latest News Section Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_section',
			),
			'color_section_featured_blocks_section' => array(
				'label' => __( 'Featured Blocks Section Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_section',
			),
			'color_section_team_section'            => array(
				'label' => __( 'Team Section Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_section',
			),
			'color_section_cta_section'             => array(
				'label' => __( 'CTA Section Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_section',
			),
			'color_section_portfolio_section'       => array(
				'label' => __( 'Portfolio Section Color Options', 'education-soul-pro' ),
				'panel' => 'color_panel_section',
			),

		);
		return $choices;
	}

endif;

if ( ! function_exists( 'education_soul_get_numbers_dropdown_options' ) ) :

	/**
	 * Returns numbers dropdown options.
	 *
	 * @since 1.0.0
	 *
	 * @param int    $min Min.
	 * @param int    $max Max.
	 * @param string $prefix Prefix.
	 * @param string $suffix Suffix.
	 *
	 * @return array Options array.
	 */
	function education_soul_get_numbers_dropdown_options( $min = 1, $max = 4, $prefix = '', $suffix = '' ) {

		$output = array();

		if ( $min <= $max ) {
			for ( $i = $min; $i <= $max; $i++ ) {
				$string       = $prefix . $i . $suffix;
				$output[ $i ] = $string;
			}
		}

		return $output;

	}

endif;

if ( ! function_exists( 'education_soul_get_home_sections_options' ) ) :

	/**
	 * Returns home sections options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function education_soul_get_home_sections_options() {

		$choices = array(
			'featured-slider'    => array(
				'label'    => __( 'Featured Slider', 'education-soul-pro' ),
				'template' => 'template-parts/home/featured-slider',
			),
			'call-to-action'     => array(
				'label'    => __( 'Call To Action', 'education-soul-pro' ),
				'template' => 'template-parts/home/call-to-action',
			),
			'news-and-events'    => array(
				'label'    => __( 'News and Events', 'education-soul-pro' ),
				'template' => 'template-parts/home/news-and-events',
			),
			'services'           => array(
				'label'    => __( 'Services', 'education-soul-pro' ),
				'template' => 'template-parts/home/services',
			),
			'featured-blocks'    => array(
				'label'    => __( 'Featured Blocks', 'education-soul-pro' ),
				'template' => 'template-parts/home/featured-blocks',
			),
			'latest-news'        => array(
				'label'    => __( 'Latest News', 'education-soul-pro' ),
				'template' => 'template-parts/home/latest-news',
			),
			'testimonials'       => array(
				'label'    => __( 'Testimonials', 'education-soul-pro' ),
				'template' => 'template-parts/home/testimonials',
			),
			'team'               => array(
				'label'    => __( 'Team', 'education-soul-pro' ),
				'template' => 'template-parts/home/team',
			),
			'gallery'            => array(
				'label'    => __( 'Gallery', 'education-soul-pro' ),
				'template' => 'template-parts/home/gallery',
			),
			'special-page'       => array(
				'label'    => __( 'Special Page', 'education-soul-pro' ),
				'template' => 'template-parts/home/special-page',
			),
			'front-page-widgets' => array(
				'label'    => __( 'Front Page Widgets', 'education-soul-pro' ),
				'template' => 'template-parts/home/front-page-widgets',
			),
		);
		$output  = apply_filters( 'education_soul_filter_home_sections_options', $choices );
		return $output;

	}

endif;

